@@ -320,7 +320,7 @@ static const EL_BNDRY_VEC *d_ortho_get_bound_1_1d(BNDRY_FLAGS *vec,
 						  const BAS_FCTS *thisptr)
 {
   FUNCNAME("d_get_bound2_1d");
-  DEF_EL_VEC_D_ORTHO_1_1D(BNDRY, rvec_space);
+  static DEF_EL_VEC_D_ORTHO_1_1D(BNDRY, rvec_space);
   BNDRY_FLAGS *rvec = vec ? vec : rvec_space->vec;
   int i;
 
