@@ -204,7 +204,7 @@ static const EL_BNDRY_VEC *get_bound2_1d(BNDRY_FLAGS *vec,
 					 const BAS_FCTS *thisptr)
 {
   FUNCNAME("get_bound2_1d");
-  DEF_EL_VEC_2_1D(BNDRY, rvec_space);
+  static DEF_EL_VEC_2_1D(BNDRY, rvec_space);
   BNDRY_FLAGS *rvec = vec ? vec : rvec_space->vec;
   int i;
 
