@@ -352,7 +352,7 @@ static const EL_BNDRY_VEC *d_ortho_get_bound_1_2d(BNDRY_FLAGS *vec,
 						  const BAS_FCTS *thisptr)
 {
   FUNCNAME("d_get_bound2_2d");
-  DEF_EL_VEC_D_ORTHO_1_2D(BNDRY, rvec_space);
+  static DEF_EL_VEC_D_ORTHO_1_2D(BNDRY, rvec_space);
   BNDRY_FLAGS *rvec = vec ? vec : rvec_space->vec;
   int i;
 
@@ -751,7 +751,7 @@ static const EL_BNDRY_VEC *d_ortho_get_bound_2_2d(BNDRY_FLAGS *vec,
 						  const BAS_FCTS *thisptr)
 {
   FUNCNAME("d_get_bound2_2d");
-  DEF_EL_VEC_D_ORTHO_2_2D(BNDRY, rvec_space);
+  static DEF_EL_VEC_D_ORTHO_2_2D(BNDRY, rvec_space);
   BNDRY_FLAGS *rvec = vec ? vec : rvec_space->vec;
   int i;
 
