@@ -36,6 +36,10 @@
 /*                                                                          */
 /*--------------------------------------------------------------------------*/
 
+#ifdef HAVE_CONFIG_H
+# include "config.h" /* probably a good idea to pull this one in here ... */
+#endif
+
 #include "alberta.h"
 
 #define MESH_DIM 3
