@@ -621,7 +621,7 @@ void mesh2off_1d(FILE *gvf,
   if (mesh->parametric) {
     bool not_all, fast = false;
 
-    not_all = mesh->parametric->not_all && !ref_deg == 1;
+    not_all = mesh->parametric->not_all && !(ref_deg == 1);
 
     if ((coords = get_lagrange_coords(mesh)) != NULL) {
 
